<?php

declare(strict_types = 1);

namespace Drupal\Tests\sparql_entity_storage\Kernel;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Cache\MemoryCache\MemoryCache;

/**
 * A variant of the memory cache backend that allows to log called methods.
 */
class TestMemoryBackend extends MemoryCache {

  /**
   * The name of the state variable used to log the calls.
   */
  const STATE_VARIABLE_NAME = 'views_test_memory_backend';

  /**
   * Logs the calls to the state backend.
   *
   * @param string $method
   *   The method that was called.
   * @param string $cid
   *   The CID related to the call.
   * @param bool $has_return
   *   Whether the call had return values. Defaults to FALSE. Always false for
   *   set() calls.
   */
  protected function log(string $method, string $cid, bool $has_return = FALSE): void {
    $calls = \Drupal::state()->get(self::STATE_VARIABLE_NAME, []);
    $calls[] = [
      'method' => $method,
      'cid' => $cid,
      'has_return' => $has_return,
    ];
    \Drupal::state()->set(self::STATE_VARIABLE_NAME, $calls);
  }

  /**
   * {@inheritdoc}
   */
  public function get($cid, $allow_invalid = FALSE) {
    $return = parent::get($cid, $allow_invalid);
    $this->log(__FUNCTION__, $cid, !empty($return));
    return $return;
  }

  /**
   * {@inheritdoc}
   */
  public function set($cid, $data, $expire = Cache::PERMANENT, ?array $tags = []): void {
    parent::set($cid, $data, $expire, $tags);
    $this->log(__FUNCTION__, $cid);
  }

}
