<?php

declare(strict_types = 1);

namespace Drupal\Tests\sparql_entity_storage\Unit;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityRepository;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Tests\UnitTestCase;
use Drupal\sparql_entity_storage\Event\ActiveGraphEvent;
use Drupal\sparql_entity_storage\ParamConverter\SparqlEntityStorageConverter;
use Drupal\sparql_entity_storage\SparqlEntityStorageInterface;
use Symfony\Component\EventDispatcher\EventDispatcher;

/**
 * Test description.
 *
 * @group sparql_entity_storage
 */
final class ParameterConverterTest extends UnitTestCase {

  /**
   * Tests that invalid URIs is not queried.
   *
   * @dataProvider urisWithUnsupportedCharacters
   */
  public function testUrisWithUnsupportedCharacters(string $uri): void {
    $entity = $this->getMockBuilder(ContentEntityInterface::class)->getMock();
    $entity_storage = $this->getMockBuilder(SparqlEntityStorageInterface::class)
      ->getMock();
    $entity_storage->method('load')->willReturn($entity);

    $entity_type_manager = $this->getMockBuilder(EntityTypeManagerInterface::class)
      ->getMock();
    $entity_type_manager->method('getStorage')->with('foo')->willReturn($entity_storage);
    $entity_repository = $this->getMockBuilder(EntityRepository::class)
      ->disableOriginalConstructor()
      ->getMock();
    $entity_repository->method('getTranslationFromContext')->willReturn($this->returnArgument(0));
    $event_dispatcher = $this->getMockBuilder(EventDispatcher::class)
      ->disableOriginalConstructor()
      ->getMock();
    $event_dispatcher->method('dispatch')
      ->willReturnCallback(function (ActiveGraphEvent $event) {
        return $event->setGraphs(['http://foo.example.com/thing']);
      });

    $sparqlEntityStorageConverter = new SparqlEntityStorageConverter($entity_type_manager, $entity_repository, $event_dispatcher);
    $this->assertNull(
      $sparqlEntityStorageConverter->convert(
        $uri,
        ['type' => 'entity:foo'],
        'dummy name',
        []
      )
    );
  }

  /**
   * Data provider for testUrisWithUnsupportedCharacters().
   */
  public static function urisWithUnsupportedCharacters(): array {
    return [
      ['http://example.com/some space'],
      ['http://example.com/{curly-brackets}'],
      ['http://example.com/<angle-brackets>'],
      ['http://example.com/\\backslash'],
      ['http://example.com/|pipe'],
      ['http://example.com/`backtick`'],
      ['http://example.com/^caret'],
      ['http://example.com/"double-quote'],
    ];
  }

}
